@@ -1,6 +1,6 @@
 /* The RELP (reliable event logging protocol) core protocol library.
  *
- * Copyright 2008-2013 by Rainer Gerhards and Adiscon GmbH.
+ * Copyright 2008-2016 by Rainer Gerhards and Adiscon GmbH.
  *
  * This file is part of librelp.
  *
@@ -106,7 +106,7 @@ typedef struct relpEngSessLst_s {
 } relpEngSessLst_t;
 
 
-/* the RELP engine object 
+/* the RELP engine object
  * Having a specific engine object enables multiple plugins to call the
  * RELP engine at the same time. The core idea of librelp is to have no
  * static data at all and everything stored in RELP engine objects. Every
@@ -213,13 +213,13 @@ struct relpEngine_s {
 	((txnr > 999999999) ? 1 : txnr + 1)
 
 static inline int relpEngineShouldStop(relpEngine_t *pThis) {
-//pThis->dbgprint("DDDD: librelp bStop %d, ShutdownImmdt %p, immdet result %d\n", pThis->bStop, pThis->bShutdownImmdt, (pThis->bShutdownImmdt == NULL) ? 0 : *pThis->bShutdownImmdt);
 	return     pThis->bStop
 	       || (pThis->bShutdownImmdt != NULL && *pThis->bShutdownImmdt);
 }
 
 /* prototypes needed by library itself (rest is in librelp.h) */
 relpRetVal relpEngineDispatchFrame(relpEngine_t *pThis, relpSess_t *pSess, relpFrame_t *pFrame);
-void __attribute__((format(printf, 4, 5))) relpEngineCallOnGenericErr(relpEngine_t *pThis, char *eobj, relpRetVal ecode, char *fmt, ...);
+void __attribute__((format(printf, 4, 5))) relpEngineCallOnGenericErr(relpEngine_t *pThis,
+	char *eobj, relpRetVal ecode, char *fmt, ...);
 
 #endif /* #ifndef RELP_H_INCLUDED */
