@@ -42,7 +42,7 @@
 #include <stdlib.h>
 #include <ctype.h>
 #include <assert.h>
-#include <sys/select.h>
+#include <poll.h>
 #include <string.h>
 #include <errno.h>
 #include <time.h>
@@ -197,6 +197,7 @@ relpSessAcceptAndConstruct(relpSess_t **ppThis, relpSrv_t *pSrv, int sock)
 
 	CHKRet(relpSessConstruct(&pThis, pSrv->pEngine, RELP_SRV_CONN, pSrv));
 	CHKRet(relpTcpAcceptConnReq(&pThis->pTcp, sock, pSrv));
+	CHKRet(relpSessSetMaxDataSize(pThis, pSrv->maxDataSize));
 
 	*ppThis = pThis;
 
@@ -308,7 +309,7 @@ finalize_it:
 }
 
 
-/* Send a command hint to the remote peer. This function works for the 
+/* Send a command hint to the remote peer. This function works for the
  * server-side of the connection. A modified version must be used for the
  * client side (because we have different ways of sending the data). We do
  * not yet need the client side. If we do, way should think about a generic
@@ -481,24 +482,18 @@ finalize_it:
  * rgerhards, 2008-03-20
  */
 static relpRetVal
-relpSessWaitState(relpSess_t *pThis, relpSessState_t stateExpected, int timeout)
+relpSessWaitState(relpSess_t *const pThis, const relpSessState_t stateExpected, const int timeout)
 {
-	fd_set readfds;
+	struct pollfd pfd;
 	int sock;
 	int nfds;
 	struct timespec tCurr; /* current time */
 	struct timespec tTimeout; /* absolute timeout value */
-	struct timeval tvSelect;
 	relpRetVal localRet;
 
 	ENTER_RELPFUNC;
 	RELPOBJ_assert(pThis, Sess);
 
-	/* are we already ready? */
-	if(pThis->sessState == stateExpected || pThis->sessState == eRelpSessState_BROKEN) {
-		FINALIZE;
-	}
-
 	/* first read any outstanding data and process the packets. Note that this
 	 * call DOES NOT block.
 	 */
@@ -506,7 +501,7 @@ relpSessWaitState(relpSess_t *pThis, relpSessState_t stateExpected, int timeout)
 	if(localRet != RELP_RET_OK && localRet != RELP_RET_SESSION_BROKEN)
 		ABORT_FINALIZE(localRet);
 
-	/* re-check if we are already in the desired state. If so, we can immediately
+	/* check if we are already in the desired state. If so, we can immediately
 	 * return. That saves us doing a costly clock call to set the timeout. As a
 	 * side-effect, the timeout is actually applied without the time needed for
 	 * above reception. I think is is OK, even a bit logical ;)
@@ -522,22 +517,15 @@ relpSessWaitState(relpSess_t *pThis, relpSessState_t stateExpected, int timeout)
 
 	while(!relpEngineShouldStop(pThis->pEngine)) {
 		sock = relpSessGetSock(pThis);
-		tvSelect.tv_sec = tTimeout.tv_sec - tCurr.tv_sec;
-		tvSelect.tv_usec = (tTimeout.tv_nsec - tCurr.tv_nsec) / 1000000;
-		if(tvSelect.tv_usec < 0) {
-			tvSelect.tv_usec += 1000000;
-			tvSelect.tv_sec--;
-		}
-		if(tvSelect.tv_sec < 0) {
+		if(tCurr.tv_sec >= tTimeout.tv_sec) {
 			ABORT_FINALIZE(RELP_RET_TIMED_OUT);
 		}
 
-		FD_ZERO(&readfds);
-		FD_SET(sock, &readfds);
+		pfd.fd = sock;
+		pfd.events = POLLIN;
 		pThis->pEngine->dbgprint("relpSessWaitRsp waiting for data on "
-			"fd %d, timeout %d.%d\n", sock, (int) tvSelect.tv_sec,
-			(int) tvSelect.tv_usec);
-		nfds = select(sock+1, (fd_set *) &readfds, NULL, NULL, &tvSelect);
+			"fd %d, timeout %d\n", sock, timeout);
+		nfds = poll(&pfd, 1, timeout*1000);
 		if(nfds == -1) {
 			if(errno == EINTR) {
 				pThis->pEngine->dbgprint("relpSessWaitRsp select interrupted, continue\n");
@@ -546,8 +534,8 @@ relpSessWaitState(relpSess_t *pThis, relpSessState_t stateExpected, int timeout)
 				ABORT_FINALIZE(RELP_RET_SESSION_BROKEN);
 			}
 		}
-		else 
-			pThis->pEngine->dbgprint("relpSessWaitRsp select returns, "
+		else
+			pThis->pEngine->dbgprint("relpSessWaitRsp poll returns, "
 				"nfds %d, errno %d\n", nfds, errno);
 		if(relpEngineShouldStop(pThis->pEngine))
 			break;
@@ -564,8 +552,8 @@ relpSessWaitState(relpSess_t *pThis, relpSessState_t stateExpected, int timeout)
 
 finalize_it:
 	pThis->pEngine->dbgprint("relpSessWaitState returns %d\n", iRet);
-	if(	iRet == RELP_RET_TIMED_OUT || 
-		iRet == RELP_RET_SESSION_BROKEN || 
+	if(	iRet == RELP_RET_TIMED_OUT ||
+		iRet == RELP_RET_SESSION_BROKEN ||
 		relpEngineShouldStop(pThis->pEngine)) {
 		/* the session is broken! */
 		pThis->sessState = eRelpSessState_BROKEN;
@@ -677,6 +665,11 @@ relpSessTryReestablish(relpSess_t *pThis)
 								   - pUnackedEtry->pSendbuf->lenTxnr);
 		CHKRet(relpFrameRewriteTxnr(pUnackedEtry->pSendbuf, pThis->txnr));
 		pThis->txnr = relpEngineNextTXNR(pThis->txnr);
+		/* Sometimes only part of large buffer is sent before
+		 * connection was closed and bufPtr is set to non-zero value,
+		 * resulting in partial transfer. We always want to send full
+		 * buffer in new connection hence this bufPtr value reset. */
+		pUnackedEtry->pSendbuf->bufPtr = 0;
 		CHKRet(relpSendbufSendAll(pUnackedEtry->pSendbuf, pThis, 0));
 		pUnackedEtry = pUnackedEtry->pNext;
 	}
@@ -688,7 +681,7 @@ finalize_it:
 
 
 /* callback when the "open" command has been processed
- * Most importantly, this function needs to check if we are 
+ * Most importantly, this function needs to check if we are
  * compatible with the server-provided offers and terminate if
  * not. If we are, we must set our own parameters to match the
  * server-provided ones. Please note that the offer processing here
@@ -811,12 +804,17 @@ relpSessConnect(relpSess_t *pThis, int protFamily, unsigned char *port, unsigned
 			ABORT_FINALIZE(RELP_RET_OUT_OF_MEMORY);
 	}
 
+	if (pThis->pCurrRcvFrame != NULL) {
+		relpFrameDestruct(&pThis->pCurrRcvFrame);
+	}
+
 	/* (re-)init some counters */
 	pThis->txnr = 1;
 	pThis->sessType = eRelpSess_Client;	/* indicate we have a client session */
 
 	CHKRet(relpTcpConstruct(&pThis->pTcp, pThis->pEngine, RELP_CLT_CONN, pThis->pClt));
 	CHKRet(relpTcpSetUsrPtr(pThis->pTcp, pThis->pUsr));
+	CHKRet(relpTcpSetConnTimeout(pThis->pTcp, pThis->connTimeout));
 	if(pThis->bEnableTLS) {
 		CHKRet(relpTcpEnableTLS(pThis->pTcp));
 		if(pThis->bEnableTLSZip) {
@@ -925,6 +923,15 @@ relpSessSetTimeout(relpSess_t *pThis, unsigned timeout)
 	LEAVE_RELPFUNC;
 }
 
+relpRetVal
+relpSessSetConnTimeout(relpSess_t *pThis, int connTimeout)
+{
+	ENTER_RELPFUNC;
+	RELPOBJ_assert(pThis, Sess);
+	pThis->connTimeout = connTimeout;
+	LEAVE_RELPFUNC;
+}
+
 relpRetVal
 relpSessSetClientIP(relpSess_t *pThis, unsigned char *ip)
 {
@@ -984,6 +991,13 @@ relpSessSetUsrPtr(relpSess_t *pThis, void *pUsr)
 	LEAVE_RELPFUNC;
 }
 
+relpRetVal relpSessSetMaxDataSize(relpSess_t *pThis, size_t maxSize) {
+	ENTER_RELPFUNC;
+	RELPOBJ_assert(pThis, Sess);
+	pThis->maxDataSize = maxSize;
+	LEAVE_RELPFUNC;
+}
+
 relpRetVal
 relpSessSetAuthMode(relpSess_t *pThis, relpAuthMode_t authmode)
 {
