@@ -1,6 +1,6 @@
 /* The mapping for relp over TCP.
  *
- * Copyright 2008-2013 by Rainer Gerhards and Adiscon GmbH.
+ * Copyright 2008-2016 by Rainer Gerhards and Adiscon GmbH.
  *
  * This file is part of librelp.
  *
@@ -40,12 +40,12 @@
 #include "relp.h"
 
 typedef enum { relpTCP_RETRY_none = 0,
-       relpTCP_RETRY_handshake = 1,
-       relpTCP_RETRY_recv = 2, 
-       relpTCP_RETRY_send = 3 } relpTcpRtryState_t;
+	relpTCP_RETRY_handshake = 1,
+	relpTCP_RETRY_recv = 2,
+	relpTCP_RETRY_send = 3 } relpTcpRtryState_t;
 
 #define RELP_SRV_CONN 0	/**< this conection is a server connection */
-#define RELP_CLT_CONN 1	/**< this conection is a client connection */	
+#define RELP_CLT_CONN 1	/**< this conection is a client connection */
 
 
 /* The tcp module uses an extended version of the permittedPeers structure,
@@ -83,7 +83,7 @@ typedef struct tcpPermittedPeers_s {
 	tcpPermittedPeerEntry_t *peer;
 } tcpPermittedPeers_t;
 
-/* the RELPTCP object 
+/* the RELPTCP object
  * rgerhards, 2008-03-16
  */
 typedef struct relpTcp_s {
@@ -144,7 +144,8 @@ relpRetVal relpTcpLstnInit(relpTcp_t *pThis, unsigned char *pLstnPort, int ai_fa
 relpRetVal relpTcpAcceptConnReq(relpTcp_t **ppThis, int sock, relpSrv_t *pSrv);
 relpRetVal relpTcpRcv(relpTcp_t *pThis, relpOctet_t *pRcvBuf, ssize_t *pLenBuf);
 relpRetVal relpTcpSend(relpTcp_t *pThis, relpOctet_t *pBuf, ssize_t *pLenBuf);
-relpRetVal relpTcpConnect(relpTcp_t *pThis, int family, unsigned char *port, unsigned char *host, unsigned char *clientIP);
+relpRetVal relpTcpConnect(relpTcp_t *pThis, int family, unsigned char *port,
+	unsigned char *host, unsigned char *clientIP);
 relpRetVal relpTcpEnableTLS(relpTcp_t *pThis);
 relpRetVal relpTcpEnableTLSZip(relpTcp_t *pThis);
 relpRetVal relpTcpSetDHBits(relpTcp_t *pThis, int bits);
